summaryrefslogtreecommitdiffstats
path: root/components/wifi/wifi_service.h
diff options
context:
space:
mode:
authorskyostil <skyostil@chromium.org>2015-06-02 12:03:48 -0700
committerCommit bot <commit-bot@chromium.org>2015-06-02 19:05:11 +0000
commitb0daa011ba68aa9079f31925faa9a7ca88894770 (patch)
tree8fb2c57a520058df58dba9ba34906af098f715f3 /components/wifi/wifi_service.h
parent3f2a3abd4acdd336e4c76ce963663507bd05e7bd (diff)
downloadchromium_src-b0daa011ba68aa9079f31925faa9a7ca88894770.zip
chromium_src-b0daa011ba68aa9079f31925faa9a7ca88894770.tar.gz
chromium_src-b0daa011ba68aa9079f31925faa9a7ca88894770.tar.bz2
components: Remove use of MessageLoopProxy and deprecated MessageLoop APIs
This patch was mostly autogenerated with https://codereview.chromium.org/1010073002/. BUG=465354 Review URL: https://codereview.chromium.org/1144153004 Cr-Commit-Position: refs/heads/master@{#332440}
Diffstat (limited to 'components/wifi/wifi_service.h')
-rw-r--r--components/wifi/wifi_service.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/components/wifi/wifi_service.h b/components/wifi/wifi_service.h
index ebb7439..9c60786 100644
--- a/components/wifi/wifi_service.h
+++ b/components/wifi/wifi_service.h
@@ -12,7 +12,6 @@
#include "base/callback.h"
#include "base/memory/ref_counted.h"
-#include "base/message_loop/message_loop_proxy.h"
#include "base/threading/sequenced_worker_pool.h"
#include "base/values.h"
#include "components/wifi/wifi_export.h"
@@ -108,9 +107,9 @@ class WIFI_EXPORT WiFiService {
std::string* error) = 0;
// Set observers to run when |NetworksChanged| and |NetworksListChanged|
// events needs to be sent. Notifications are posted on |message_loop_proxy|.
virtual void SetEventObservers(
- scoped_refptr<base::MessageLoopProxy> message_loop_proxy,
+ scoped_refptr<base::SingleThreadTaskRunner> task_runner,
const NetworkGuidListCallback& networks_changed_observer,
const NetworkGuidListCallback& network_list_changed_observer) = 0;
@@ -108,9 +107,9 @@ class WIFI_EXPORT WiFiService {
std::string* error) = 0;
// Set observers to run when |NetworksChanged| and |NetworksListChanged|
- // events needs to be sent. Notifications are posted on |message_loop_proxy|.
+ // events needs to be sent. Notifications are posted on |task_runner|.
virtual void SetEventObservers(